<?php
/**
 * @version     2.0.0
 * @package     Com_YendifVideoShare
 * @subpackage  Mod_YendifVideoShare_Categories
 * @author      PluginsWare Interactive Pvt. Ltd <admin@yendifplayer.com>
 * @copyright   Copyright (c) 2012 - 2022 PluginsWare Interactive Pvt. Ltd. All Rights Reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined( '_JEXEC' ) or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Language\Text;
use PluginsWare\Component\YendifVideoShare\Site\Helper\YendifVideoShareHelper;
use PluginsWare\Component\YendifVideoShare\Site\Helper\YendifVideoShareRoute;
use PluginsWare\Module\YendifVideoShareCategories\Site\Helper\YendifVideoShareCategoriesHelper;

$app = Factory::getApplication();

$items = YendifVideoShareCategoriesHelper::getItems( $params );

// Vars
$columns = (int) $params->get( 'no_of_cols', 3 );
$column = 0;
$column_no = floor( 12 / $columns );

$column_class = 'col-sm-' . $column_no;

$player_ratio = $params->get( 'ratio', 56.25 );
$image_ratio  = $params->get( 'image_ratio', $player_ratio );

// Import CSS
$wa = $app->getDocument()->getWebAssetManager();

if ( ! $wa->assetExists( 'style', 'com_yendifvideoshare.site' ) ) {
	$wr = $wa->getRegistry();
	$wr->addRegistryFile( 'media/com_yendifvideoshare/joomla.asset.json' );
}

$wa->useStyle( 'com_yendifvideoshare.site' );

if ( $css = $params->get( 'custom_css' ) ) {
    $wa = $app->getDocument()->getWebAssetManager();
    $wa->addInlineStyle( $css );
}
?>

<div class="yendif-video-share mod-yendifvideoshare-categories">
	<?php if ( empty( $items ) ) : ?>
		<p class="text-muted">
			<?php echo Text::_( 'MOD_YENDIFVIDEOSHARE_CATEGORIES_NO_ITEMS_FOUND' ); ?>
		</p>
	<?php else : ?>
		<div class="yendif-video-share-grid">
			<div class="row">
				<?php foreach ( $items as $i => $item ) : 
					if ( $column >= $columns ) {
						echo '</div><div class="row">';
						$column = 0;
					}

					$route = YendifVideoShareRoute::getCategoryRoute( $item, (int) $params->get( 'itemid', 0 ) );
					$item_link = Route::_( $route );
					?>
					<div class="<?php echo $column_class; ?>">
						<div class="card mb-3">
							<a href="<?php echo $item_link; ?>" class="yendif-video-share-responsive-item" style="padding-bottom: <?php echo (float) $image_ratio; ?>%">
								<div class="yendif-video-share-image" style="background-image: url( '<?php echo YendifVideoShareHelper::getImage( $item ); ?>' );">&nbsp;</div>
							</a>

							<div class="card-body">
								<a href="<?php echo $item_link; ?>" class="card-link">
									<?php 
									echo $item->title; 

									if ( $params->get( 'show_videos_count' ) ) {
										$count = YendifVideoShareHelper::getVideosCount( $item->id, $params );
										echo ' (' . $count . ')';
									}
									?>
								</a>

								<?php if ( $params->get( 'show_excerpt' ) && ! empty( $item->description ) ) : ?>
									<div class="yendif-video-share-excerpt mt-2">
										<?php echo YendifVideoShareHelper::Truncate( $item->description, $params->get( 'excerpt_length' ) ); ?>
									</div>
								<?php endif; ?>
							</div>					
						</div>
					</div>
					<?php
					if ( $column >= $columns ) echo '</div>';
					$column++;
				endforeach; ?>
			</div>

			<?php if ( $params->get( 'show_more_btn' ) && $params->get( 'more_btn_link' ) ) : ?>
				<a class="btn btn-primary" href="<?php echo $params->get( 'more_btn_link' ); ?>">
					<?php echo $params->get( 'more_btn_label', Text::_( 'MOD_YENDIFVIDEOSHARE_CATEGORIES_SHOW_MORE_BUTTON_LABEL' ) ); ?>
				</a>
			<?php endif; ?>
		</div>		
	<?php endif; ?>
</div>
