<?php
/**
 * @version     2.0.0
 * @package     Com_YendifVideoShare
 * @subpackage  Mod_YendifVideoShare_Playlist
 * @author      PluginsWare Interactive Pvt. Ltd <admin@yendifplayer.com>
 * @copyright   Copyright (c) 2012 - 2022 PluginsWare Interactive Pvt. Ltd. All Rights Reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined( '_JEXEC' ) or die;

use \Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;
use PluginsWare\Component\YendifVideoShare\Site\Helper\YendifVideoShareHelper;
use PluginsWare\Component\YendifVideoShare\Site\Helper\YendifVideoSharePlayer;
use PluginsWare\Module\YendifVideoSharePlaylist\Site\Helper\YendifVideoSharePlaylistHelper;

$app = Factory::getApplication();

$global = ComponentHelper::getParams( 'com_yendifvideoshare' );

$options = array(
	'image_ratio',
	'ratio',
	'show_excerpt',
	'excerpt_length',
	'show_views',
	'show_rating',
	'schedule_video_publishing',
	'playlist_position',
	'playlist_width',
	'playlist_height',
	'custom_css'
);

foreach ( $options as $option ) {
	$value = $params->get( $option, 'global' );
	if ( $value == 'global' ) {
		$params->set( $option, $global->get( $option ) );
	}
}

$items = YendifVideoSharePlaylistHelper::getItems( $params );

// Player args
static $uid = 0;
$uid++;

$args = array( 
	'uid' => $uid
);

$player_options = array(
	'ratio',
	'volume',
	'autoplay',
	'autoplaylist',
	'loop',
	'controlbar',
	'playbtn',
	'playpause',
	'currenttime',
	'progress',
	'duration',
	'volumebtn',
	'fullscreen',
	'embed',
	'share',
	'download'
);

foreach ( $player_options as $option ) {
	$value = $params->get( $option, 'global' );
	if ( $value != 'global' ) {
		$args[ $option ] = $value;
	}
}

// Import CSS & JS
$wa = $app->getDocument()->getWebAssetManager();

if ( ! $wa->assetExists( 'style', 'com_yendifvideoshare.site' ) ) {
	$wr = $wa->getRegistry();
	$wr->addRegistryFile( 'media/com_yendifvideoshare/joomla.asset.json' );
}

$wa->useStyle( 'com_yendifvideoshare.site' )
	->useScript( 'com_yendifvideoshare.site' );

$inlineStyle = $params->get( 'custom_css' );

if ( $params->get( 'playlist_position' ) == 'right' ) {
	$inlineStyle .= "
		#yendif-video-share-playlist-" . $uid . " .yendif-video-share-playlist-player {
			width: calc(100% - " . (int) $params->get( 'playlist_width', 250 ) . "px);
		}

		#yendif-video-share-playlist-" . $uid . " .yendif-video-share-playlist-videos {
			width: " . (int) $params->get( 'playlist_width', 250 ) . "px;
		}

		@media only screen and (max-width: 768px) {
			#yendif-video-share-playlist-" . $uid . " .yendif-video-share-playlist-player,
			#yendif-video-share-playlist-" . $uid. " .yendif-video-share-playlist-videos {
				width: 100%;
			}

			#yendif-video-share-playlist-" . $uid . " .yendif-video-share-playlist-videos {
				max-height: " . (int) $params->get( 'playlist_height', 250 ) . "px;
			}
		}
	";
} else {
	$inlineStyle .= "
		#yendif-video-share-playlist-" . $uid . " .yendif-video-share-playlist-videos {
			max-height: " . (int) $params->get( 'playlist_height', 250 ) . "px;
		}
	";
}

$wa->addInlineStyle( $inlineStyle );
?>

<div id="yendif-video-share-playlist-<?php echo $uid; ?>" class="yendif-video-share mod-yendifvideoshare-playlist">
	<?php if ( empty( $items ) ) : ?>
		<p class="text-muted">
			<?php echo Text::_( 'MOD_YENDIFVIDEOSHARE_PLAYLIST_NO_ITEMS_FOUND' ); ?>
		</p>
	<?php else : ?>
		<div class="yendif-video-share-playlist">
			<!-- Player -->
			<div class="yendif-video-share-playlist-player">
				<?php
				$args['videoid'] = $items[0]->id;
				echo YendifVideoSharePlayer::load( $args, $params );
				?>
			</div>

			<!-- Playlist -->
			<div class="yendif-video-share-playlist-videos <?php echo $params->get( 'playlist_position', 'right' ); ?>">
				<div class="yendif-video-share-playlist-items">
					<?php foreach ( $items as $index => $item ) :
						$args['videoid']  = $item->id;
						$args['autoplay'] = 1;

						$iframe_src = YendifVideoSharePlayer::getURL( $args );
						?>
						<div class="yendif-video-share-playlist-item<?php if( $index == 0 ) echo ' active'; ?>" data-index="<?php echo (int) $index; ?>" data-src="<?php echo $iframe_src; ?>">
							<div class="d-flex p-2">
								<div class="flex-shrink-0">
									<div class="yendif-video-share-responsive-item" style="padding-bottom: <?php echo (float) $params->get( 'image_ratio', 56.25 ); ?>%">
										<div class="yendif-video-share-image" style="background-image: url( '<?php echo YendifVideoShareHelper::getImage( $item ); ?>' );">&nbsp;</div>

										<?php if ( ! empty( $item->duration ) ) : ?>
											<span class="yendif-video-share-duration small"><?php echo $item->duration; ?></span>
										<?php endif; ?> 
									</div>
								</div>
								<div class="flex-grow-1 ms-3">
									<div class="yendif-video-share-title">
										<?php echo $item->title; ?>
									</div>

									<?php if ( $params->get( 'show_excerpt' ) && ! empty( $item->description ) ) : ?>
										<div class="yendif-video-share-excerpt small text-muted">
											<?php echo YendifVideoShareHelper::Truncate( $item->description, $params->get( 'excerpt_length' ) ); ?>
										</div>
									<?php endif; ?>

									<?php if ( $params->get( 'show_rating' ) ) : ?>
										<div class="yendif-video-share-ratings-small">
											<span class="yendif-video-share-ratings-stars">
												<span class="yendif-video-share-ratings-current" style="width: <?php echo (float) $item->rating; ?>%;"></span>
											</span>
										</div>
									<?php endif; ?> 

									<?php if ( $params->get( 'show_views' ) ) : ?>
										<div class="yendif-video-share-views-count">
											<?php
											Text::sprintf(
												'MOD_YENDIFVIDEOSHARE_PLAYLIST_VIEWS_COUNT', 
												$item->views
											);
											?>
										</div>
									<?php endif; ?>
								</div>
							</div>
						</div>
					<?php endforeach; ?>
				</div>
			</div>
		</div>	
	<?php endif; ?>
</div>
