<?php
/**
 * @version     2.0.0
 * @package     Com_YendifVideoShare
 * @author      PluginsWare Interactive Pvt. Ltd <admin@yendifplayer.com>
 * @copyright   Copyright (c) 2012 - 2022 PluginsWare Interactive Pvt. Ltd. All Rights Reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace PluginsWare\Component\YendifVideoShare\Site\Helper;

\defined( '_JEXEC' ) or die;

use \Joomla\CMS\Component\ComponentHelper;
use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Multilanguage;
use \Joomla\CMS\Router\Route;

/**
 * Class YendifVideoShareRoute.
 *
 * @since  2.0.0
 */
abstract class YendifVideoShareRoute {

	/**
	 * Get the URL route for a category
	 *
	 * @param   object  $item      The category object.
	 * @param   int     $itemId    The id of the menu item.
	 * @param   mixed   $language  The id of the language being used.
	 * @param   string  $format    The view format.
	 *
	 * @return  string  The link to the category
	 *
	 * @since   2.0.0
	 */
	public static function getCategoryRoute( $item, $itemId = 0, $language = 0, $format = '' ) {
		if ( empty( $itemId ) ) {
			$params = ComponentHelper::getParams( 'com_yendifvideoshare' );
			$itemId = (int) $params->get( 'itemid_category' );
		}

		if ( $itemId == -1 ) {
			$link = self::getRoute( 'category', $item );
		} else {
			$link = 'index.php?option=com_yendifvideoshare&view=category&id=' . $item->id . ':' . $item->alias;

			if ( $itemId > 1 ) {
				$link .= '&Itemid=' . $itemId;
			}
		}

		if ( $language && $language !== '*' && Multilanguage::isEnabled() ) {
			$link .= '&lang=' . $language;
		}

		if ( $format ) {
			$link .= '&format=' . $format;
		}

		return $link;
	}

	/**
	 * Get the URL route for a video
	 *
	 * @param   object  $item      The video object.
	 * @param   int     $itemId    The id of the menu item.
	 * @param   mixed   $language  The id of the language being used.
	 *
	 * @return  string  The link to the video
	 *
	 * @since   2.0.0
	 */
	public static function getVideoRoute( $item, $itemId = 0, $language = 0 ) {
		if ( empty( $itemId ) ) {
			$params = ComponentHelper::getParams( 'com_yendifvideoshare' );
			$itemId = (int) $params->get( 'itemid_video' );
		}

		if ( $itemId == -1 ) {
			$link = self::getRoute( 'video', $item );
		} else {
			$link = 'index.php?option=com_yendifvideoshare&view=video&id=' . $item->id . ':' . $item->alias;

			if ( $itemId > 1 ) {
				$link .= '&Itemid=' . $itemId;
			}
		}

		if ( $language && $language !== '*' && Multilanguage::isEnabled() ) {
			$link .= '&lang=' . $language;
		}
		
		return $link;
	}

	/**
	 * Get the URL route for a search
	 *
	 * @param   int     $itemId    The id of the menu item.
	 * @param   mixed   $language  The id of the language being used.
	 *
	 * @return  string  The link to the search
	 *
	 * @since   2.0.0
	 */
	public static function getSearchRoute( $itemId = 0, $language = 0 ) {
		$link = 'index.php?option=com_yendifvideoshare&view=search';

		if ( $itemId > 1 ) {
			$link .= '&Itemid=' . (int) $itemId;
		}

		if ( $language && $language !== '*' && Multilanguage::isEnabled() ) {
			$link .= '&lang=' . $language;
		}

		return $link;
	}

	private static function getRoute( $view, $item ) {
		$is_exact_match_found = 0;
		
		// Check if there is a menu item with the given ID value for the view
		$itemId = self::findMenuItem( $view, $item->id );
		if ( $itemId > 0 ) {
			$is_exact_match_found = 1;
		}
		
		// Check if there is a menu item atleast for the view
		if ( empty( $itemId ) ) {
			$itemId = self::findMenuItem( $view );
		}
		
		// Fallback to the current itemId
		if ( empty( $itemId ) ) {
			$itemId = Factory::getApplication()->input->getInt( 'Itemid', 0 );
		}

		// Build route
		if ( $is_exact_match_found ) {
			$route = "index.php?Itemid=$itemId";
		} else {
			$route = "index.php?option=com_yendifvideoshare&view=$view&id={$item->id}:{$item->alias}";

			if ( ! empty( $itemId ) ) {
				$route .= "&Itemid=$itemId";
			}
		}
		
		return $route;	
	}

	private static function findMenuItem( $view, $id = 0, $itemId = 0 ) {	
		$db = Factory::getDbo();
		
		$query = sprintf(
			'SELECT id FROM #__menu WHERE link=%s AND published=1 LIMIT 1',
			$db->quote( "index.php?option=com_yendifvideoshare&view=$view&id=$id" )
		);

		$db->setQuery( $query );

		if ( $id = $db->loadResult() ) {
			$itemId = $id;
		}
		
		return $itemId;
	}

}
