<?php
/**
 * @version    2.0.1
 * @package    Com_YendifVideoShare
 * @author     PluginsWare Interactive Pvt. Ltd <admin@yendifplayer.com>
 * @copyright  Copyright (c) 2012 - 2022 PluginsWare Interactive Pvt. Ltd. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace PluginsWare\Component\YendifVideoShare\Site\Model;

// No direct access
\defined( '_JEXEC' ) or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\MVC\Model\ItemModel;
use \Joomla\CMS\Table\Table;

/**
 * Class VideoModel.
 *
 * @since  2.0.0
 */
class VideoModel extends ItemModel {

	public $_item;	

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return  void
	 *
	 * @since   2.0.0
	 * @throws  Exception
	 */
	protected function populateState() {
		$app = Factory::getApplication();

		$params = $app->getParams();

		// Filter state information
		$id = $app->input->getInt( 'id' );
		$this->setState( 'video.id', $id );

		// Load the parameters
		$this->setState( 'params', $params );
	}

	/**
	 * Method to get an object.
	 *
	 * @param   integer  $id  The id of the object to get.
	 *
	 * @return  mixed    Object on success, false on failure.
	 *
	 * @since   2.0.0
	 * @throws  Exception
	 */
	public function getItem( $id = null ) {
		if ( $this->_item === null ) {
			$db = Factory::getDbo();
			$user = Factory::getUser();							

			$query = $db->getQuery( true );

			$query->select( '*' );
			$query->from( $db->quoteName( '#__yendifvideoshare_videos' ) );

			// Filter by id
			if ( empty( $id ) ) {
				$id = $this->getState( 'video.id' );
			}

			$query->where( 'id = ' . (int) $id );

			// Filter by start and end dates
			$params = $this->getState( 'params' );

			if ( $params && $params->get( 'schedule_video_publishing' ) ) {
				$nullDate = $db->getNullDate();
				$nowDate  = Factory::getDate()->toSql();

				$query->where( '(userid = ' . $user->id . ' OR published_up IS NULL OR published_up = ' . $db->quote( $nullDate ) . ' OR published_up <= ' . $db->quote( $nowDate ) . ')' );
				$query->where( '(userid = ' . $user->id . ' OR published_down IS NULL OR published_down = ' . $db->quote( $nullDate ) . ' OR published_down >= ' . $db->quote( $nowDate ) . ')' );
			}

			// Filter by published state
			$query->where( '(userid = ' . $user->id . ' OR  state = 1)' );

        	$db->setQuery( $query );
			$this->_item = $db->loadObject();
		}	
		
		if ( ! empty( $this->_item ) ) {
			$this->_item->category = $this->getCategory();
			$this->_item->relatedVideos = $this->getRelatedVideos();
		}

		return $this->_item;
	}

	/**
	 * Get an instance of Table class
	 *
	 * @param   string  $type    Name of the Table class to get an instance of.
	 * @param   string  $prefix  Prefix for the table class name. Optional.
	 * @param   array   $config  Array of configuration values for the Table object. Optional.
	 *
	 * @return  Table|bool  Table if success, false on failure.
	 * 
	 * @since   2.0.0
	 */
	public function getTable( $type = 'Video', $prefix = 'Administrator', $config = array() ) {
		return parent::getTable( $type, $prefix, $config );
	}	

	/**
	 * Get the category item
	 * 
	 * @return  mixed  Object on success, false on failure.
	 * 
	 * @since   2.0.0
	 */
	public function getCategory() {
		if ( empty( $this->_item ) ) {
			return false;
		}

		$db = Factory::getDbo();
		$query = $db->getQuery( true );

		$query
			->select( '*' )
			->from( $db->quoteName( '#__yendifvideoshare_categories' ) )
			->where( $db->quoteName( 'id' ) . ' = ' . (int) $this->_item->catid )
			->where( $db->quoteName( 'state' ) . ' = 1' );

		$db->setQuery( $query );
        $item = $db->loadObject();

		return $item;
	}
	
	/**
	 * Get related videos
	 *
	 * @return  mixed  Object on success, false on failure.
	 * 
	 * @since   2.0.0
	 */
	public function getRelatedVideos() {
		if ( empty( $this->_item ) ) {
			return false;
		}
		
		$params = $this->getState( 'params' );
		$limit = $this->getState( 'list.limit', 10 );
		
		$db = Factory::getDbo();
		$query = $db->getQuery( true );

		$query->select( '*' );
		$query->from( $db->quoteName( '#__yendifvideoshare_videos' ) );

		$query->where( 'id != ' . (int) $this->_item->id );
		$query->where( 'catid = ' . (int) $this->_item->catid );
		
		if ( $params && $params->get( 'schedule_video_publishing' ) ) {
			$nullDate = $db->getNullDate();
			$nowDate  = Factory::getDate()->toSql();

			$query->where( '(published_up IS NULL OR published_up = ' . $db->quote( $nullDate ) . ' OR published_up <= ' . $db->quote( $nowDate ) . ')' );
			$query->where( '(published_down IS NULL OR published_down = ' . $db->quote( $nullDate ) . ' OR published_down >= ' . $db->quote( $nowDate ) . ')' );
		}

		$query->where( $db->quoteName( 'state' ) . ' = 1' );		
		$query->order( 'RAND()' );

        $db->setQuery( $query, 0, $limit );
        $items = $db->loadObjectList();
		
		return $items;		
	}
	
}
