<?php
/**
 * @version    2.0.1
 * @package    Com_YendifVideoShare
 * @author     PluginsWare Interactive Pvt. Ltd <admin@yendifplayer.com>
 * @copyright  Copyright (c) 2012 - 2022 PluginsWare Interactive Pvt. Ltd. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined( '_JEXEC' ) or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;
use PluginsWare\Component\YendifVideoShare\Site\Helper\YendifVideoShareHelper;
use PluginsWare\Component\YendifVideoShare\Site\Helper\YendifVideoShareRoute;

$app = Factory::getApplication();

// Vars
$columns = (int) $this->params->get( 'no_of_cols', 3 );
$column = 0;
$column_no = floor( 12 / $columns );

$column_class = 'col-sm-' . $column_no;
$popup_class  = $this->params->get( 'enable_popup' ) ? ' yendif-video-share-popup' : '';

$player_ratio = $this->params->get( 'ratio', 56.25 );
$image_ratio  = $this->params->get( 'image_ratio', $player_ratio );

// Import CSS
$wa = $app->getDocument()->getWebAssetManager();

if ( $this->params->get( 'enable_popup' ) ) {
	$wa->useStyle( 'com_yendifvideoshare.popup' )
		->useScript( 'com_yendifvideoshare.popup' )
		->useScript( 'com_yendifvideoshare.site' );
}

$wa->useStyle( 'com_yendifvideoshare.site' );

if ( $css = $this->params->get( 'custom_css' ) ) {
    $wa->addInlineStyle( $css );
}
?>

<div id="yendif-video-share-category" class="yendif-video-share category">
	<?php if ( $this->params->get( 'show_page_heading' ) ) : ?>
		<div class="page-header">
			<h1>
				<?php if ( $this->escape( $this->params->get( 'page_heading' ) ) ) : ?>
					<?php echo $this->escape( $this->params->get( 'page_heading' ) ); ?>
				<?php else : ?>
					<?php echo $this->escape($this->params->get( 'page_title' ) ); ?>
				<?php endif; ?>

				<?php if ( $this->params->get( 'show_videos_count' ) ) : ?>
            		(<?php echo YendifVideoShareHelper::getVideosCount( $this->category->id, $this->params ); ?>)
            	<?php endif; ?>

				<?php if ( $this->params->get( 'show_feed' ) && $this->params->get( 'feed_icon' ) ) : ?>
					<a href="<?php echo YendifVideoShareRoute::getCategoryRoute( $this->category, $this->params->get( 'itemid_category' ), 0, 'feed' ); ?>" class="yendif-video-share-feed-btn" target="_blank">
						<img src="<?php echo $this->params->get( 'feed_icon' ); ?>" />
					</a>
				<?php endif; ?>
			</h1>
		</div>		
	<?php endif; ?>

	<?php if ( ! empty( $this->category->description ) ) : ?>
		<p class="yendif-video-share-description"><?php echo $this->category->description; ?></p>
	<?php endif; ?>

	<div class="yendif-video-share-grid<?php echo $popup_class; ?> mb-4" data-player_ratio="<?php echo (float) $player_ratio; ?>">
		<div class="row">
			<?php foreach ( $this->items as $i => $item ) : 
				if ( $column >= $columns ) {
					echo '</div><div class="row">';
					$column = 0;
				}

				$route = YendifVideoShareRoute::getVideoRoute( $item, $this->params->get( 'itemid_video' ) );
				$item_link = Route::_( $route );

				if ( $this->params->get( 'enable_popup' ) ) {
					$item_link = 'javascript:void(0)';
				}			

				$iframe_src = URI::root() . 'index.php?option=com_yendifvideoshare&view=player&id=' . $item->id . "&format=raw&autoplay=1";
				?>
				<div class="yendif-video-share-grid-item yendif-video-share-video-<?php echo (int) $item->id; ?> <?php echo $column_class; ?>" data-mfp-src="<?php echo $iframe_src; ?>">
					<div class="card mb-3">
						<a href="<?php echo $item_link; ?>" class="yendif-video-share-responsive-item" style="padding-bottom: <?php echo (float) $image_ratio; ?>%">
							<div class="yendif-video-share-image" style="background-image: url( '<?php echo YendifVideoShareHelper::getImage( $item ); ?>' );">&nbsp;</div>
							
							<svg class="yendif-video-share-svg-icon yendif-video-share-svg-icon-play" width="32" height="32" viewBox="0 0 32 32">
								<path d="M16 0c-8.837 0-16 7.163-16 16s7.163 16 16 16 16-7.163 16-16-7.163-16-16-16zM16 29c-7.18 0-13-5.82-13-13s5.82-13 13-13 13 5.82 13 13-5.82 13-13 13zM12 9l12 7-12 7z"></path>
							</svg>

							<?php if ( ! empty( $item->duration ) ) : ?>
								<span class="yendif-video-share-duration"><?php echo $item->duration; ?></span>
							<?php endif; ?> 
						</a>

						<div class="card-body">
							<div class="yendif-video-share-title">
								<a href="<?php echo $item_link; ?>" class="card-link"><?php echo $this->escape( $item->title ); ?></a>
							</div>

							<?php if ( $this->params->get( 'show_excerpt' ) && ! empty( $item->description ) ) : ?>
								<div class="yendif-video-share-excerpt mt-2">
									<?php echo YendifVideoShareHelper::Truncate( $item->description, $this->params->get( 'excerpt_length' ) ); ?>
								</div>
							<?php endif; ?>

							<?php if ( $this->params->get( 'show_rating' ) ) : ?>
								<div class="yendif-video-share-ratings-small mt-1">
									<span class="yendif-video-share-ratings-stars">
										<span class="yendif-video-share-ratings-current" style="width: <?php echo (float) $item->rating; ?>%;"></span>
									</span>
								</div>
							<?php endif; ?> 

							<?php if ( $this->params->get( 'show_views' ) ) : ?>
								<div class="yendif-video-share-views-count mt-1 small">
									<?php
									Text::printf(
										'COM_YENDIFVIDEOSHARE_VIDEOS_VIEWS_COUNT', 
										$item->views
									);
									?>
								</div>
							<?php endif; ?>
						</div>					
					</div>
				</div>
				<?php
				if ( $column >= $columns ) echo '</div>';
				$column++;
			endforeach; ?>
		</div>

		<?php echo $this->pagination->getListFooter(); ?>
	</div>		

	<?php if ( ! empty( $this->subCategories ) ) : $column = 0; ?>
		<?php if ( ! empty( $this->items ) ) : ?>
			<p class="lead"><?php echo Text::_( 'COM_YENDIFVIDEOSHARE_TITLE_SUBCATEGORIES' ); ?></p>
		<?php endif; ?>

		<div class="yendif-video-share-grid">
			<div class="row">
				<?php foreach ( $this->subCategories as $i => $item ) : 
					if ( $column >= $columns ) {
						echo '</div><div class="row">';
						$column = 0;
					}

					$route = YendifVideoShareRoute::getCategoryRoute( $item, $this->params->get( 'itemid_category' ) );
					$item_link = Route::_( $route );
					?>
					<div class="<?php echo $column_class; ?>">
						<div class="card mb-3">
							<a href="<?php echo $item_link; ?>" class="yendif-video-share-responsive-item" style="padding-bottom: <?php echo $image_ratio; ?>%">
								<div class="yendif-video-share-image" style="background-image: url( '<?php echo YendifVideoShareHelper::getImage( $item ); ?>' );">&nbsp;</div>
							</a>

							<div class="card-body">
								<div class="yendif-video-share-title">
									<a href="<?php echo $item_link; ?>" class="card-link">
										<?php
										echo $this->escape( $item->title );

										if ( $this->params->get( 'show_videos_count' ) ) {
											$count = YendifVideoShareHelper::getVideosCount( $item->id, $this->params );
											echo ' (' . $count . ')';
										}
										?>
									</a>
								</div>

								<?php if ( $this->params->get( 'show_excerpt' ) && ! empty( $item->description ) ) : ?>
									<div class="yendif-video-share-excerpt mt-2">
										<?php echo YendifVideoShareHelper::Truncate( $item->description, $this->params->get( 'excerpt_length' ) ); ?>
									</div>
								<?php endif; ?>
							</div>					
						</div>
					</div>
					<?php
					if ( $column >= $columns ) echo '</div>';
					$column++;
				endforeach; ?>
			</div>
		</div>
	<?php endif; ?>
</div>
