<?php
/**
 * @version    2.0.1
 * @package    Com_YendifVideoShare
 * @author     PluginsWare Interactive Pvt. Ltd <admin@yendifplayer.com>
 * @copyright  Copyright (c) 2012 - 2022 PluginsWare Interactive Pvt. Ltd. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined( '_JEXEC' ) or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Date\Date;
use Joomla\CMS\Factory;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;
use PluginsWare\Component\YendifVideoShare\Site\Helper\YendifVideoShareHelper;
use PluginsWare\Component\YendifVideoShare\Site\Helper\YendifVideoShareHtml;
use PluginsWare\Component\YendifVideoShare\Site\Helper\YendifVideoSharePlayer;
use PluginsWare\Component\YendifVideoShare\Site\Helper\YendifVideoShareRoute;

$app = Factory::getApplication();

// Import CSS & JS
$wa = $app->getDocument()->getWebAssetManager();

if ( $this->params->get( 'enable_popup' ) ) {
	$wa->useStyle( 'com_yendifvideoshare.popup' )
		->useScript( 'com_yendifvideoshare.popup' );
}

$wa->useStyle( 'com_yendifvideoshare.site' );

if ( $css = $this->params->get( 'custom_css' ) ) {
    $wa->addInlineStyle( $css );
}

$wa->useScript( 'com_yendifvideoshare.site' );

$inlineScript = "
	if ( typeof( yendif ) === 'undefined' ) {
		var yendif = {};
	};

	yendif.baseurl = '" . URI::root() . "';
	yendif.userid = " . Factory::getUser()->get( 'id' ) . ";
	yendif.allow_guest_like = " . $this->params->get( 'allow_guest_like' ) . ";
	yendif.allow_guest_rating = " . $this->params->get( 'allow_guest_rating' ) . ";
	yendif.message_login_required = '" . Text::_( 'COM_YENDIFVIDEOSHARE_ALERT_MSG_LOGIN_REQUIRED' ) . "';
";

$wa->addInlineScript( $inlineScript, [ 'position' => 'before' ], [], [ 'com_yendifvideoshare.site' ] );
?>

<div id="yendif-video-share-video" class="yendif-video-share video">
	<?php if ( $this->params->get( 'show_page_heading' ) ) : ?>
		<div class="page-header">
			<h1>
				<?php if ( $this->escape( $this->params->get( 'page_heading' ) ) ) : ?>
					<?php echo $this->escape( $this->params->get( 'page_heading' ) ); ?>
				<?php else : ?>
					<?php echo $this->escape($this->params->get( 'page_title' ) ); ?>
				<?php endif; ?>
			</h1>
		</div>
	<?php endif; ?>
    
    <div class="yendif-video-share-item">
		<?php if ( $this->params->get( 'show_search' ) ) :
			$route = YendifVideoShareRoute::getSearchRoute(); 
			?>
			<form class="yendif-video-share-search-form mb-4" action="<?php echo Route::_( $route ); ?>" method="GET" role="search">
				<?php if ( ! YendifVideoShareHelper::isSEF() ) : ?>
					<input type="hidden" name="option" value="com_yendifvideoshare" />
					<input type="hidden" name="view" value="search" />
					<input type="hidden" name="Itemid" value="<?php echo $app->input->getInt( 'Itemid' ); ?>" />
				<?php endif; ?>

				<div class="input-group">
					<input type="text" name="s" class="form-control" placeholder="<?php echo Text::_( 'JSEARCH_FILTER_SUBMIT' ); ?> ..." />
					<button class="btn btn-primary" type="submit">
						<span class="icon-search icon-white" aria-hidden="true"></span> <?php echo Text::_( 'JSEARCH_FILTER_SUBMIT' ); ?>
					</button>
				</div>
			</form>
		<?php endif; ?>

		<?php
		// Player
		$args = array( 
			'videoid' => $this->item->id,
			'Itemid'  => $app->input->getInt( 'Itemid' )
		);

		echo '<div class="mb-4">' . YendifVideoSharePlayer::load( $args, $this->params ) . '</div>';

		if ( $this->params->get( 'show_rating' ) || $this->params->get( 'show_likes' ) ) : ?>
			<?php if ( $this->params->get( 'show_rating' ) ) : ?>
				<div id="yendif-video-share-ratings-widget" class="float-md-start mb-1">
					<?php echo YendifVideoShareHtml::RatingWidget( $this->item, $this->params ); ?>
				</div>
			<?php endif; ?>	
			
			<?php if ( $this->params->get( 'show_likes' ) ) : ?>
				<div id="yendif-video-share-likes-dislikes-widget" class="float-md-end mb-1">
					<?php echo YendifVideoShareHtml::LikesDislikesWidget( $this->item, $this->params ); ?>
				</div>
			<?php endif; ?>

			<div class="clearfix"></div>
		<?php endif;

		// Description	
		if ( $this->params->get( 'show_description' ) && ! empty( $this->item->description ) ) {
			echo '<div class="mb-4">' . $this->item->description . '</div>';
		}

		// Meta
		$meta = array();

		if ( $this->params->get( 'show_category' ) ) { // Categories
			$meta[] = sprintf(
				'<div class="yendif-video-share-meta-category"><span class="icon-folder-open icon-fw"></span> %s: <a href="%s">%s</a></div>',
				Text::_( 'COM_YENDIFVIDEOSHARE_TITLE_CATEGORY' ),
				YendifVideoShareRoute::getCategoryRoute( $this->item->category, $this->params->get( 'itemid_category' ) ),
				$this->escape( $this->item->category->title )
			);
		}

		if ( $this->params->get( 'show_user' ) ) { // User
			$meta[] = sprintf(
				'<div class="yendif-video-share-meta-user"><span class="icon-user icon-fw"></span> %s: %s</div>',
				Text::_( 'COM_YENDIFVIDEOSHARE_TITLE_USER' ),
				Factory::getUser( $this->item->userid )->username
			);
		}
		          
		if ( $this->params->get( 'show_views' ) ) { // Views
			$meta[] = sprintf(
				'<div class="yendif-video-share-meta-views"><span class="icon-eye icon-fw"></span> %s: %s</div>',
				Text::_( 'COM_YENDIFVIDEOSHARE_TITLE_VIEWS' ),
				$this->item->views
			);
		}	

		if ( $this->params->get( 'show_date' ) ) { // Date
			$date  = ( ! empty( $this->item->published_up ) && $this->item->published_up !== '0000-00-00 00:00:00' ) ? $this->item->published_up : $this->item->created_date;
			$jdate = new Date( $date );
			$prettyDate = $jdate->format( Text::_( 'DATE_FORMAT_LC2' ) );

			$meta[] = sprintf(
				'<div class="yendif-video-share-meta-date"><span class="icon-calendar icon-fw"></span> %s: %s</div>',
				Text::_( 'COM_YENDIFVIDEOSHARE_TITLE_DATE_ADDED' ),
				$prettyDate
			);
		}
		
		if ( count( $meta ) ) {
			printf( 
				'<div class="yendif-video-share-meta mb-4">%s</div>' ,
				implode( '', $meta )
			);
		}

		// Comments
		if ( $this->params->get( 'comments' ) != 'none' ) {
			echo $this->loadTemplate( 'comments' );
		}
		
		// Relates Videos
		if ( $this->params->get( 'show_related' ) ) {
			echo $this->loadTemplate( 'related' );
		}
        ?>
    </div>
</div>