<?php
/**
 * @version    2.0.1
 * @package    Com_YendifVideoShare
 * @author     PluginsWare Interactive Pvt. Ltd <admin@yendifplayer.com>
 * @copyright  Copyright (c) 2012 - 2022 PluginsWare Interactive Pvt. Ltd. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined( '_JEXEC' ) or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;
use PluginsWare\Component\YendifVideoShare\Site\Helper\YendifVideoShareHelper;

HTMLHelper::_( 'bootstrap.tooltip' );

$wa = $this->document->getWebAssetManager();
$wa->useScript( 'keepalive' )
	->useScript( 'form.validate' )
	->useScript( 'com_yendifvideoshare.form' );

$canEdit  = YendifVideoShareHelper::canUserEdit( $this->item );
$canState = Factory::getUser()->authorise( 'core.edit.state','com_yendifvideoshare' );
?>

<div class="video-edit front-end-edit">
	<?php if ( ! $canEdit ) : ?>
		<?php $app->enqueueMessage( Text::_( 'COM_YENDIFVIDEOSHARE_NO_PERMISSION_EDIT' ), 'error' ); ?>
	<?php else : ?>
		<?php if ( ! empty( $this->item->id ) ) : ?>
			<h1><?php echo Text::_( 'COM_YENDIFVIDEOSHARE_EDIT_VIDEO_TITLE' ); ?></h1>
		<?php else: ?>
			<h1><?php echo Text::_( 'COM_YENDIFVIDEOSHARE_ADD_VIDEO_TITLE' ); ?></h1>
		<?php endif; ?>

		<form id="form-video" action="<?php echo Route::_( 'index.php?option=com_yendifvideoshare&task=videoform.save' ); ?>" method="post" class="form-validate form-horizontal" enctype="multipart/form-data">
			<input type="hidden" name="jform[id]" value="<?php echo isset( $this->item->id ) ? (int) $this->item->id : ''; ?>" />
			<input type="hidden" name="jform[ordering]" value="<?php echo isset( $this->item->ordering ) ? (int) $this->item->ordering : ''; ?>" />
			<input type="hidden" name="jform[checked_out]" value="<?php echo isset( $this->item->checked_out ) ? $this->item->checked_out : ''; ?>" />
			<input type="hidden" name="jform[checked_out_time]" value="<?php echo isset( $this->item->checked_out_time ) ? $this->item->checked_out_time : ''; ?>" />

			<?php echo HTMLHelper::_( 'uitab.startTabSet', 'myTab', array( 'active' => 'video' ) ); ?>
				
			<?php echo HTMLHelper::_( 'uitab.addTab', 'myTab', 'video', Text::_( 'COM_YENDIFVIDEOSHARE_TAB_VIDEO', true ) ); ?>
				<?php echo $this->form->renderField( 'title' ); ?>
				<?php echo $this->form->renderField( 'catid' ); ?>
				
				<?php
				$options = array(
					'video' => Text::_( 'COM_YENDIFVIDEOSHARE_FORM_OPTION_VIDEO_TYPE_VIDEO' )
				);

				if ( $this->params->get( 'allow_youtube' ) ) {
					$options['youtube'] = Text::_( 'COM_YENDIFVIDEOSHARE_FORM_OPTION_VIDEO_TYPE_YOUTUBE' );
				}

				if ( $this->params->get( 'allow_vimeo' ) ) {
					$options['vimeo'] = Text::_( 'COM_YENDIFVIDEOSHARE_FORM_OPTION_VIDEO_TYPE_VIMEO' );
				}

				if ( $this->params->get( 'allow_hls_dash' ) ) {
					$options['rtmp'] = Text::_( 'COM_YENDIFVIDEOSHARE_FORM_OPTION_VIDEO_TYPE_RTMP' );
				}
				?>
				<div class="control-group"<?php if ( count( $options ) == 1 ) { echo ' style="display: none;"'; } ?>>
					<div class="control-label">
						<label id="jform_type-lbl" for="jform_type"><?php echo Text::_( 'COM_YENDIFVIDEOSHARE_FORM_LBL_VIDEO_TYPE' ); ?></label>
					</div>
					<div class="controls">
						<select id="jform_type" name="jform[type]" class="form-select">
							<?php
							foreach ( $options as $value => $text ) {								
								$selected = isset( $this->item->type ) ? $this->item->type : 'video';

								printf(
									'<option value="%s"%s>%s</option>',
									$value,
									( $value == $selected ? ' selected="selected"' : '' ),
									$text
								);
							}
							?>
						</select>
					</div>
				</div>

				<?php echo $this->form->renderField( 'mp4' ); ?>
				<?php echo $this->form->renderField( 'mp4_hd' );	?>
				<?php if ( ! empty( $this->item->webm ) ) echo $this->form->renderField( 'webm' ); ?>
				<?php if ( ! empty( $this->item->ogv ) ) echo $this->form->renderField( 'ogv' ); ?>
				<?php echo $this->form->renderField( 'youtube' ); ?>
				<?php echo $this->form->renderField( 'vimeo' ); ?>
				<?php echo $this->form->renderField( 'hls' ); ?>
				<?php echo $this->form->renderField( 'dash' ); ?>
				<?php echo $this->form->renderField( 'image' ); ?>
				<?php if ( $this->params->get( 'allow_subtitle' ) ) echo $this->form->renderField( 'captions' ); ?>
				<?php echo $this->form->renderField( 'duration' ); ?>
				<?php echo $this->form->renderField( 'description' ); ?>
				<div class="control-group">
					<?php if ( ! $canState ) : ?>
						<div class="control-label"><?php echo $this->form->getLabel( 'state' ); ?></div>
						<div class="controls">
							<?php
							$state = isset( $this->item->state ) ? $this->item->state : 0;

							switch ( $state ) {
								case 1:
									echo Text::_( 'JPUBLISHED' );
									break;
								case 0:
									echo Text::_( 'JUNPUBLISHED' );
									break;
							}
							?>
						</div>
						<input type="hidden" name="jform[state]" value="<?php echo $state; ?>" />
					<?php else : ?>
						<div class="control-label"><?php echo $this->form->getLabel( 'state' ); ?></div>
						<div class="controls"><?php echo $this->form->getInput( 'state' ); ?></div>
					<?php endif; ?>
				</div>
				<?php if ( $canState && $this->params->get( 'schedule_video_publishing' ) ) echo $this->form->renderField( 'published_up' ); ?>
				<?php if ( $canState && $this->params->get( 'schedule_video_publishing' ) ) echo $this->form->renderField( 'published_down' ); ?>
			<?php echo HTMLHelper::_( 'uitab.endTab' ); ?>

			<?php echo HTMLHelper::_( 'uitab.addTab', 'myTab', 'Advanced', Text::_( 'COM_YENDIFVIDEOSHARE_TAB_ADVANCED', true ) ); ?>
				<?php echo $this->form->renderField( 'meta_keywords' ); ?>
				<?php echo $this->form->renderField( 'meta_description' ); ?>
			<?php echo HTMLHelper::_( 'uitab.endTab' ); ?>

			<div class="control-group">
				<div class="controls">
					<?php if ( $this->canSave ) : ?>
						<button type="submit" class="validate btn btn-primary">
							<span class="fas fa-check" aria-hidden="true"></span>
							<?php echo Text::_( 'JSUBMIT' ); ?>
						</button>
					<?php endif; ?>
					<a class="btn btn-danger" href="<?php echo Route::_( 'index.php?option=com_yendifvideoshare&task=videoform.cancel' ); ?>" title="<?php echo Text::_( 'JCANCEL' ); ?>">
					   <span class="fas fa-times" aria-hidden="true"></span>
						<?php echo Text::_( 'JCANCEL' ); ?>
					</a>
				</div>
			</div>

			<input type="hidden" name="option" value="com_yendifvideoshare" />
			<input type="hidden" name="task" value="videoform.save" />
			<?php echo HTMLHelper::_( 'form.token' ); ?>
		</form>
	<?php endif; ?>
</div>
